==> Botan-1.1.3.tgz: Botan-1.1.3/include/dl_algo.h <==
/*************************************************
* DL Scheme Header File                          *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#ifndef BOTAN_DL_ALGO_H__
#define BOTAN_DL_ALGO_H__

#include <botan/x509.h>
#include <botan/pkcs8.h>
#include <botan/dl_param.h>

namespace Botan {

/*************************************************
* DL Public Key                                  *
*************************************************/
class DL_Scheme_PublicKey : public virtual X509_PublicKey
   {
   public:
      const DL_Group& get_domain() const { return group; }
      const BigInt& get_y() const { return y; }
      bool check_params() const;
   protected:
      DL_Scheme_PublicKey() { expected_group = DL_Group::Uninitialized; }
      void dl_initialize(DL_Group::GroupType);
      void dl_initialize(DL_Group::GroupType, const DL_Group&, const BigInt&);
      SecureVector<byte> DER_encode_pub() const;
      SecureVector<byte> DER_encode_params() const;
      void BER_decode_pub(DataSource&);
      void BER_decode_params(DataSource&);
      DL_Group group;
      BigInt y;
   private:
      DL_Group::GroupType expected_group;
   };

/*************************************************
* DL Private Key                                 *
*************************************************/
class DL_Scheme_PrivateKey : public virtual DL_Scheme_PublicKey,
                             public virtual PKCS8_PrivateKey
   {
   public:
      const BigInt& get_x() const { return x; }
   protected:
      SecureVector<byte> DER_encode_priv() const;
      void BER_decode_priv(DataSource&);
      BigInt x;
   };

}

#endif

==> Botan-1.3.6.tgz: Botan-1.3.6/include/dl_algo.h <==
/*************************************************
* DL Scheme Header File                          *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#ifndef BOTAN_DL_ALGO_H__
#define BOTAN_DL_ALGO_H__

#include <botan/dl_param.h>
#include <botan/x509_key.h>
#include <botan/pkcs8.h>

namespace Botan {

/*************************************************
* DL Public Key                                  *
*************************************************/
class DL_Scheme_PublicKey : public virtual X509_PublicKey
   {
   public:
      const DL_Group& get_domain() const { return group; }
      const BigInt& get_y() const { return y; }
      bool check_params() const;
   protected:
      void dl_initialize(const DL_Group&, const BigInt&);
      const BigInt& group_p() const { return group.get_p(); }
      const BigInt& group_q() const { return group.get_q(); }
      const BigInt& group_g() const { return group.get_g(); }
      SecureVector<byte> DER_encode_pub() const;
      void BER_decode_pub(DataSource&);

      DL_Group group;
      BigInt y;
   };

/*************************************************
* DL Private Key                                 *
*************************************************/
class DL_Scheme_PrivateKey : public virtual DL_Scheme_PublicKey,
                             public virtual PKCS8_PrivateKey
   {
   public:
      const BigInt& get_x() const { return x; }
   protected:
      SecureVector<byte> DER_encode_priv() const;
      void BER_decode_priv(DataSource&);
      BigInt x;
   };

}

#endif
